;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                       Role of Heterogeneity - PG Game               ;;
;;                      Voluntary Contribution Mechanism               ;;
;;                           Testbed -  Aug 2016                       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;
;; Global Variables ;;
;;;;;;;;;;;;;;;;;;;;;;


globals [
  
;; number of turtles of each strategy
  num-freeriders
  num-perfectconditionalcoops
  num-abovediagonal-condcoops
  num-belowdiagonal-condcoops
  num-alt-condcoops
  num-trianglecont
  num-random
  
;; global parameters  
  profit-pg               ; multiplication factor for a public good
  profit-pvtg             ; multiplication factor for a private good
  endowment               ; initial endowment

  
;; payoff of all turtles playing each strategy
  freeride-payoff                  ; total payoff of freeriders
  perfectcondcooperate-payoff      ; total payoff of perfect conditional cooperators
  abovecondcooperate-payoff        ; total payoff of above diagonal conditional cooperators
  belowconcooperate-payoff         ; total payoff of below diagonal conditional cooperators
  alternatingcondcoop-payoff       ; total payoff of alternating conditional cooperators
  tri-contributors-payoff          ; total payoff of triangular contributors
  random-payoff                    ; total payoff of random contributors
  
  
  
;; contribution
  average-contribution      ; average contribution for the round
  total-contribution        ; total contribution for the round
  
  
] 

;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Turtle-owned Variables ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;

turtles-own[
  contribution                    ; contribution to public good of each turtle
  pvt_income                      ; income invested in private good
  payoff                          ; own turtle payoff
  strategy                        ; turtle strategy type (freerider - cooperator - condcooperator) 
  others-avg-contributions        ; the avergage contributions of others
  memory-1                        ; list that records the average contribution of others
]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;
; Setup Procedure ;
;;;;;;;;;;;;;;;;;;;

to setup
  clear-all
  turtle-count      ;; count number of turtles created for each stratey
  setup-turtles     ;; setup the turtles and distribute them randomly
  reset-ticks
end

;; count number of turtles created for each stratey according to sliders in interface
to turtle-count
  set num-freeriders Number-of-Freeriders
  set num-perfectconditionalcoops Number-of-PerfectConditionalCooperators
  set num-abovediagonal-condcoops Number-of-Above-Diagonal-ConditionalCooperators
  set num-belowdiagonal-condcoops Number-of-Below-Diagonal-ConditionalCooperators
  set num-alt-condcoops Number-of-Alt-ConditionalCooperation
  set num-trianglecont Number-of-TriangularContributors
  set num-random Number-of-RandomContributors
end

;; setup the turtles and distribute them randomly
to setup-turtles
   make-turtles            ;; create turtles and set color
   setup-common-variables  ;; set the variables that all turtles share
end


;;create turtles playing each strategy and assign a color to each group
to make-turtles
  crt num-freeriders [set strategy "freeride" set color red]
  crt num-perfectconditionalcoops [set strategy "perfect-conditional-cooperation" set color brown ]
  crt num-abovediagonal-condcoops  [set strategy "above-conditional-cooperation" set color orange ]
  crt num-belowdiagonal-condcoops  [set strategy "below-conditional-cooperation" set color orange + 3 ]
  crt num-alt-condcoops [set strategy "alt-conditional-cooperation" set color cyan ]
  crt num-trianglecont [ set strategy "triangular-contribution" set color blue ]
  crt num-random [ set strategy "random" set color magenta ]
end


;;set the variables that all turtles share
to setup-common-variables
  set profit-pg Profit-Factor-PublicGood                       ;; multiplication factor for PG set to value of slider  
  set profit-pvtg Profit-Factor_PvtGood                        ;; multiplication factor for private good set to value of slider 
  set endowment  Initial-Endowment                             ;; endowment set to value of slider

  ask turtles [ 
    setxy random-xcor random-ycor            ;; turtles scattered randomly on grid
    set shape "person"                       ;; turtles have shape of people
    set size 3                               ;; turtle displayed size
  ]

  ;;initiate memories
ask turtles [
  set memory-1 []   ; others' average contribution memory
]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;
; Random-Setup Procedure ;
;;;;;;;;;;;;;;;;;;;;;;;;;;

to random-setup
  clear-all
  setup-random-turtles     ;; setup the turtles and distribute them randomly 
  random-turtle-count
  reset-ticks
end


;; setup the turtles and distribute them randomly
to setup-random-turtles
   make-random-turtles            ;; create turtles and set color
   assign-strategies       ;; each turtle 
   setup-random-common-variables  ;; set the variables that all turtles share
end


;;create turtles playing each strategy and assign a color to each group
to make-random-turtles
crt Number-of-Agents
end


to assign-strategies
  ask turtles [
    let RS random 6
    
    if RS = 0
    [set strategy "freeride" set color red]
    
    if RS = 1
    [set strategy "perfect-conditional-cooperation" set color brown ]

    if RS = 2
    [set strategy "above-conditional-cooperation" set color orange ]
    
    if RS = 3
    [set strategy "below-conditional-cooperation" set color orange + 3 ]

    if RS = 4
    [set strategy "alt-conditional-cooperation" set color cyan ]
    
    if RS = 5
    [ set strategy "triangular-contribution" set color blue ]
    
  ]
  end

;;set the variables that all turtles share
to setup-random-common-variables
  set profit-pg Profit-Factor-PublicGood                       ;; multiplication factor for PG set to value of slider  
  set profit-pvtg Profit-Factor_PvtGood                        ;; multiplication factor for private good set to value of slider 
  set endowment  Initial-Endowment                             ;; endowment set to value of slider

  ask turtles [ 
    setxy random-xcor random-ycor            ;; turtles scattered randomly on grid
    set shape "person"                       ;; turtles have shape of people
    set size 3                               ;; turtle displayed size
  ]

  ;;initiate memories
ask turtles [
  set memory-1 []   ; others' average contribution memory
]
end


;; count number of turtles created for each stratey according to sliders in interface
to random-turtle-count
  set num-freeriders count turtles with [strategy ="freeride"]
  set num-perfectconditionalcoops count turtles with [strategy ="perfect-conditional-cooperation"]
  set num-abovediagonal-condcoops count turtles with [strategy ="above-conditional-cooperation"]
  set num-belowdiagonal-condcoops count turtles with [strategy ="below-conditional-cooperation"]
  set num-alt-condcoops count turtles with [strategy ="alt-conditional-cooperation"]
  set num-trianglecont count turtles with [strategy ="triangular-contribution"]
  set num-random count turtles with [strategy ="random"]
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;
; Go Procedure ;
;;;;;;;;;;;;;;;;


to go
set endowment  Initial-Endowment          ;; each round endowment is reset at the value of the initial endowment of slider       

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Logic Flowchart:                                                             ;;
;; (1) Turtles play strategy (decide contribution according to strategy)        ;;
;; (2) Turtles calculate private income = endowment - contribution              ;;
;; (3) Total contribution and average contribution for the round are calculated ;;
;; (4) Turtles calculate their payoff                                           ;;
;; (5) Turtles update memories and calculate average contributions of others    ;;
;; (6) Payoffs for each strategy are calculated                                 ;;                          
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

ask turtles[
  play-strategy                                ;; turtles play one round
  set pvt_income (endowment - contribution)    ;; after turtles decide their contribution they calculate their private income
]

calc-contribution                              ;; calculate total and average contribution of the round 
   
ask turtles [  
  calc-turtles-payoff            ;; each turtle calculates its own payoff
  calc-other-contributions       ;; each turtle calculates the average contribution of other turtles
  update-memory                  ;; each turtle updates its memory lists  
]
calc-payoff                                    ;; calculate the payoff of each strategy


tick
end


                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;                                      
                                       ;;   Turtles play strategy   ;;
                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
                                       
to play-strategy
 if strategy = "freeride" [freeride]
 if strategy = "perfect-conditional-cooperation" [perfect-conditional-cooperate]
 if strategy = "above-conditional-cooperation" [above-conditional-cooperate]
 if strategy = "below-conditional-cooperation" [below-conditional-cooperate]
 if strategy = "alt-conditional-cooperation" [alt-conditional-cooperate]
 if strategy = "triangular-contribution" [triangle-cont]
 if strategy = "random" [random-contribution]
end



;; freeride strategy ;;
;; freerider contrdibutes either 0 or 1
;; There's a 75% chance, free-rider will contribute zero, 25% freerider will contribute 1

to freeride
 let s random-float 1
 
    ifelse s < 0.75 
    [set contribution 0]
    [set contribution 1]    
end


;; perfect conditional cooperation ;;
;; contribution in round 1 = random between 0 and 1/2 endowment
;; contribution in round t = average contribution of others in round t-1  + random normal (0.04,0.63)

to perfect-conditional-cooperate
   ifelse ticks < 1                       
   [ set contribution round max list 0 random (endowment / 2 ) ]   
   [ ifelse item 0 memory-1 < endowment / 2
     [ set contribution round max list 0 ( item 0 memory-1 + random-normal 0.04 0.63 ) ]          
     [ set contribution round min list endowment ( item 0 memory-1 + random-normal 0.04 0.63 ) ] ]     
end



;; above diagonal conditional cooperators ;;
;; they are the kind of conditional cooperators whose contributions are slightly above the average of others'
;; contribution in round 1 = random-normal (4.3, 2.54)
;; contribution in round t:
;;                     if average contribution of others in t-1 <= 0.2 * endowment
;;                            contribution = average contribution of others in round t-1 + random normal (1.9 2.2)
;;                     if average contribution of others in t-1 > 0.2 * endowment
;;                            contribution = average contribution of others in round t-1 + random normal (1.09, 1.8)

to above-conditional-cooperate 
   ifelse ticks < 1
   [set contribution round max list 0 random-normal 4.3 2.54]    
    [ifelse item 0 memory-1 <= endowment / 5
      [set contribution  round max list 0 (item 0 memory-1 + random-normal 1.9 2.2)
        if contribution > endowment    ;; to ensure contribution doesn't exceed endowment
        [set contribution endowment] ]         
   [set contribution round min list endowment (item 0 memory-1 + random-normal 1.09 1.8)]  
     if contribution < 0               ;; to ensure contribution doesn't go below zero
     [set contribution 0] ] 
end
  


;; below diagonal conditional cooperators ;;
;; they are the kind of conditional cooperators whose contributions are below the average of others'
;; contribution in round 1 = random normal (2.7,2.2)
;; contribution in round t:
;;                     if average contribution of others in t-1 <= 0.3 * endowment
;;                            contribution = average contribution of others in round t-1 + random normal (-0.7, 1.07)
;;                     if average contribution of others in t-1 between 0.4 * endowmenent and 0.5 * endowment
;;                            contribution = average contribution of others in round t-1 + random normal (-2.3, 1.07)
;;                     if average contribution of others in t-1 > 0.5 * endowment
;;                            contribution = average contribution of others in round t-1 + random normal (-4.07, 2.3)

to below-conditional-cooperate
 if ticks < 1
  [ set contribution round max list 0 random-normal 2.7 2.2 ]  
  if ticks >= 1 [  
    ifelse item 0 memory-1 <= 0.3 * endowment  
    [set contribution round max list 0 (item 0 memory-1 + random-normal -0.7 1.07 )
     if contribution > endowment
     [set contribution endowment] ]
    
    [ifelse item 0 memory-1 > 0.3 * endowment and item 0 memory-1 <= endowment / 2
     [set contribution round max list 0 (item 0 memory-1 + random-normal -2.3 1.4 )
        if contribution > endowment
       [set contribution endowment] ]
       [set contribution round max list 0 (item 0 memory-1 + random-normal -4.07 2.3 )
        if contribution > endowment
       [ set contribution endowment] ] ] ] 
end



;; alternating conditional cooperators ;;
;; they are the kind of conditional cooperators whose contributions are above (or below) the average of others till a certain contribution point (point = 3) beyond that point their
   ;; contribution pattern is reversed -- i.e their contribution becomes below (or above) the average of others
;; contribution in round 1 = random normal (3.2, 1.9)
;; contribution in round t:
;;                     if average contribution of others in t-1 is between 0 and 0.2 * endowment
;;                            contribution = average contribution of others in round t-1 + random normal (-1.3, 2.3)
;;                     if average contribution of others in t-1 is between 0.3 * endowment and 0.5 * endowment
;;                            contribution = average contribution of others in round t-1 + random normal (-0.4, 2)
;;                     if average contribution of others in t-1 is between 0.6 * endowment and 0.9 * endowment
;;                            contribution = average contribution of others in round t-1 + random normal (-2.2,2.6)
;;                     if average contribution of others in t-1 is endowment
;;                            contribution = average contribution of others in round t-1 + random normal (-3.7,3.8)


to alt-conditional-cooperate
   if ticks < 1 
   [set contribution round max list 0  random-normal 3.2 1.9] 
  
  if ticks >= 1 
  [ifelse item 0 memory-1 >= 0 and item 0 memory-1 <= endowment / 5 
    [
      set contribution round max list 0 (item 0 memory-1  + random-normal 1.3 2.3 )
      if contribution > endowment
      [set contribution endowment] ]
  [ ifelse item 0 memory-1 > endowment / 5 and item 0 memory-1 <= endowment / 2
    [set contribution round max list 0 (item 0 memory-1  + random-normal -0.4 2 )
      if contribution > endowment
      [set contribution endowment] ]

  [ ifelse item 0 memory-1 > endowment / 2 and item 0 memory-1 <= ( 0.9 * endowment )
    [set contribution round max list 0 (item 0 memory-1  + random-normal -2.2 2.6 )
      if contribution > endowment
      [set contribution endowment]]
  
    [set contribution round max list 0 (item 0 memory-1  + random-normal -3.7 3.8 )
      if contribution > endowment
      [set contribution endowment] ] ] ] ]
end



;; triangular contributors ;; 
;; agents have a significantly increasing scheme upto "some maximum" and a significantly decreasing scheme after it
;; critical point after which contribution decreases is when average contribution of others = 1/2 endowment
;; contribution in round 1 = random normal (2.4, 1.9)
;; contribution in round t:
   ;; if average contribution <= 1/2 endowment ==> agent increases contribution
      ;; contribution = average contribution of others at round t-1 + random normal (-0.4, 1.5)
   ;; if average contribution > 1/2 endowment ==> agent decreases contribution
      ;; contribution = average contribution of others at round t-1 + random normal (-5.2, 3.6)

to triangle-cont    
  ifelse ticks < 1 
  [set contribution round max list 0 random-normal 2.4 1.9]
  [ ifelse (item 0 memory-1) <= (endowment / 2 ) 
   [ set contribution round max list 0 (item 0 memory-1 + random-normal -0.4 1.5)]
   [ set contribution round max list 0 (item 0 memory-1 + random-normal -5.2 3.6)] ]
end



;; random contributors ;;
;; contribution is a random value between 0 and endowment at all rounds

to random-contribution  
  set contribution random (endowment + 1)
end



                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;                                      
                                       ;;   Calculating Contributions  ;;
                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
                                       
;; total and average contribution of round are calculated
to calc-contribution
  set total-contribution total-cont
end

to-report total-cont
  report sum [contribution] of turtles
end

to-report avg-cont
  report total-cont / count turtles
end



                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;                                      
                                       ;;       Turtle payoffs         ;;
                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; each turtle calculates its payoff for the round
;; payoff of each turtle = (profit factor of private good * private income) + (profit factor of public good/number of turtles * total contribution of all turtles)

to calc-turtles-payoff  
  if strategy = "freeride" [
   set payoff ( (profit-pvtg * pvt_income) + (profit-pg / count turtles * total-cont) )
  ]
  
  if strategy = "cooperate" [
   set payoff ( (profit-pvtg * pvt_income) + (profit-pg / count turtles * total-cont) )
  ]
  
if strategy = "perfect-conditional-cooperation" [
   set payoff ( (profit-pvtg * pvt_income) + (profit-pg / count turtles * total-cont) )
  ]


if strategy = "above-conditional-cooperation" [
   set payoff ( (profit-pvtg * pvt_income) + (profit-pg / count turtles * total-cont) )
  ]

if strategy = "below-conditional-cooperation" [
   set payoff ( (profit-pvtg * pvt_income) + (profit-pg / count turtles * total-cont) )
  ]


if strategy = "alt-conditional-cooperation" [
   set payoff ( (profit-pvtg * pvt_income) + (profit-pg / count turtles * total-cont) )
  ]

 
 if strategy = "triangular-contribution" [
   set payoff ( (profit-pvtg * pvt_income) + (profit-pg / count turtles * total-cont) )
 ]


 if strategy = "random" [
   set payoff ( (profit-pvtg * pvt_income) + (profit-pg / count turtles * total-cont) )
 ]

end


                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;                                  
                                       ;;       Calculate Others'Average Contributions       ;;
                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to calc-other-contributions
  set others-avg-contributions other-cont 
end

to-report other-cont
  report sum [contribution] of other turtles / (count turtles - 1 )
end




                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;                                      
                                       ;;       Update memories        ;;
                                       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to update-memory
   set memory-1 fput others-avg-contributions memory-1  ;; update average contribution of others memory
end




                                        ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
                                        ;;       Strategy Payoff        ;;
                                        ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
 
;; calculate the payoff of each strategy

to calc-payoff
  set freeride-payoff (get-payoff "freeride" num-freeriders)
  set perfectcondcooperate-payoff (get-payoff "perfect-conditional-cooperation" num-perfectconditionalcoops)
  set abovecondcooperate-payoff (get-payoff "above-conditional-cooperation" num-abovediagonal-condcoops)
  set belowconcooperate-payoff (get-payoff "below-conditional-cooperation" num-belowdiagonal-condcoops)
  set alternatingcondcoop-payoff (get-payoff "alt-conditional-cooperation" num-alt-condcoops)
  set tri-contributors-payoff (get-payoff "triangular-contribution" num-trianglecont)
  set random-payoff (get-payoff "random" num-random)
 
;; ask turtles to move after each round
  ask turtles [
    rt random 360
    fd 1 ]
end


;; return the payoff for a strategy if any turtles exist that are playing it
to-report get-payoff [strategy-type num-with-strategy]
  ifelse num-with-strategy > 0 [
    report ( sum [payoff] of (turtles with [strategy = strategy-type ]) ) ]
    [ report 0 ]
  end
    
@#$#@#$#@
GRAPHICS-WINDOW
238
10
483
203
16
16
4.91
1
10
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks
30.0

SLIDER
22
284
195
317
Number-of-FreeRiders
Number-of-FreeRiders
0
100
22
1
1
NIL
HORIZONTAL

SLIDER
693
283
867
316
Number-of-PerfectConditionalCooperators
Number-of-PerfectConditionalCooperators
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
29
22
214
55
Profit-Factor-PublicGood
Profit-Factor-PublicGood
2
200
5
0.1
1
NIL
HORIZONTAL

SLIDER
28
65
215
98
Profit-Factor_PvtGood
Profit-Factor_PvtGood
0
5
1
0.5
1
NIL
HORIZONTAL

BUTTON
30
154
94
187
Setup
Setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
146
154
209
187
Go
Go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
221
210
321
255
Total Contribution
total-cont
17
1
11

PLOT
470
12
1321
260
Contribution
Round
Tokens
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Total Contribution" 1.0 0 -8630108 true "" "plot total-contribution"
"Mean Contribution" 1.0 0 -2064490 true "" "plot total-contribution / count turtles"

SLIDER
27
105
217
138
Initial-Endowment
Initial-Endowment
10
20
10
10
1
NIL
HORIZONTAL

MONITOR
325
210
422
255
Mean Contribution of Round
total-cont / count turtles
17
1
11

PLOT
22
317
442
489
Free-Riders Average Contribution and Payoff
Round
Tokens
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Mean Cont" 1.0 0 -2674135 true "" "Ifelse count turtles with [strategy =\"freeride\"] = 0\n[plot 0]\n[plot mean [contribution] of (turtles with [strategy = \"freeride\" ])\n]"
"Mean Payoff" 1.0 0 -7500403 true "" "Ifelse count turtles with [strategy =\"freeride\"] = 0\n[plot 0]\n[ plot freeride-payoff / num-freeriders ]"

SLIDER
692
703
869
736
Number-of-TriangularContributors
Number-of-TriangularContributors
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
24
915
202
948
Number-of-RandomContributors
Number-of-RandomContributors
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
22
495
196
528
Number-of-Above-Diagonal-ConditionalCooperators
Number-of-Above-Diagonal-ConditionalCooperators
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
692
493
867
526
Number-of-Below-Diagonal-ConditionalCooperators
Number-of-Below-Diagonal-ConditionalCooperators
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
23
705
197
738
Number-of-Alt-ConditionalCooperation
Number-of-Alt-ConditionalCooperation
0
100
0
1
1
NIL
HORIZONTAL

PLOT
693
316
1112
486
Perfect Conditional Coops Average Contribution and Payoff
Round
Tokens
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Mean Cont" 1.0 0 -6459832 true "" "Ifelse count turtles with [strategy =\"perfect-conditional-cooperation\"] = 0\n[plot 0]\n[plot mean [contribution] of (turtles with [strategy = \"perfect-conditional-cooperation\" ])\n]"
"Mean Payoff" 1.0 0 -7500403 true "" "Ifelse count turtles with [strategy =\"perfect-conditional-cooperation\"] = 0\n[plot 0]\n[plot perfectcondcooperate-payoff / num-perfectconditionalcoops\n]"

PLOT
22
528
440
698
Above-Diagonal Conditional Coops Average Contribution and Payoff
Round
Tokens
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Mean Cont" 1.0 0 -955883 true "" "Ifelse count turtles with [strategy =\"above-conditional-cooperation\"] = 0\n[plot 0]\n[\nplot mean [contribution] of (turtles with [strategy = \"above-conditional-cooperation\" ])\n]"
"Mean Payoff" 1.0 0 -7500403 true "" "Ifelse count turtles with [strategy =\"above-conditional-cooperation\"] = 0\n[plot 0]\n[plot abovecondcooperate-payoff / num-abovediagonal-condcoops\n]"

PLOT
692
526
1110
694
Below-Diagonal Conditional Coops Average Contribution and Payoff
Round
Tokens
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Mean Cont" 1.0 0 -408670 true "" "Ifelse count turtles with [strategy =\"below-conditional-cooperation\"] = 0\n[plot 0]\n[plot mean [contribution] of (turtles with [strategy = \"below-conditional-cooperation\" ])\n]"
"Mean Payoff" 1.0 0 -7500403 true "" "Ifelse count turtles with [strategy =\"below-conditional-cooperation\"] = 0\n[plot 0] [\nplot belowconcooperate-payoff / num-belowdiagonal-condcoops\n]"

PLOT
23
737
440
906
Alternating-Diagonal Conditional Coops Average Contribution and Payoff
Round
Tokens
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Mean Cont" 1.0 0 -11221820 true "" "Ifelse count turtles with [strategy =\"alt-conditional-cooperation\"] = 0\n[plot 0]\n[plot mean [contribution] of (turtles with [strategy = \"alt-conditional-cooperation\" ])\n]"
"Mean Payoff" 1.0 0 -7500403 true "" "Ifelse count turtles with [strategy =\"alt-conditional-cooperation\"] = 0\n[plot 0] [\nplot alternatingcondcoop-payoff / num-alt-condcoops\n]"

PLOT
693
736
1108
903
Triangular Contributors Average Contribution and Payoff
Round
Tokens
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Mean Cont" 1.0 0 -13345367 true "" "Ifelse count turtles with [strategy =\"triangular-contribution\"] = 0\n[plot 0]\n[plot mean [contribution] of (turtles with [strategy = \"triangular-contribution\" ])\n]"
"Mean Payoff" 1.0 0 -7500403 true "" "Ifelse count turtles with [strategy =\"triangular-contribution\"] = 0\n[plot 0] [\nplot tri-contributors-payoff / num-trianglecont\n]"

PLOT
24
948
440
1115
Random Contributors Average Contribution and Payoff
Round
Tokens
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Mean Cont" 1.0 0 -5825686 true "" "Ifelse count turtles with [strategy =\"random\"] = 0\n[plot 0] [\nplot mean [contribution] of (turtles with [strategy = \"random\" ])\n]"
"Mean Payoff" 1.0 0 -7500403 true "" "Ifelse count turtles with [strategy =\"random\"] = 0\n[plot 0] [ \nplot random-payoff / num-random\n]"

SLIDER
1379
18
1551
51
Number-of-Agents
Number-of-Agents
0
100
17
1
1
NIL
HORIZONTAL

BUTTON
1416
53
1528
86
Random Setup
random-setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
1369
93
1457
138
Num-Freeriders
count turtles with [strategy =\"freeride\"]
17
1
11

MONITOR
1473
95
1561
140
Num-AboveCC
count turtles with [strategy =\"above-conditional-cooperation\"]
17
1
11

MONITOR
1473
146
1563
191
Num-BelowCC
count turtles with [strategy =\"below-conditional-cooperation\"]
17
1
11

MONITOR
1472
198
1561
243
Num-PerfectCC
count turtles with [strategy =\"perfect-conditional-cooperation\"]
17
1
11

MONITOR
1369
145
1458
190
Num-Tri
count turtles with [strategy =\"triangular-contribution\"]
17
1
11

MONITOR
1472
251
1563
296
Num-AltCC
count turtles with [strategy =\"alt-conditional-cooperation\"]
17
1
11

MONITOR
1370
195
1460
240
Num-Random
count turtles with [strategy =\"random\"]
17
1
11

@#$#@#$#@
## WHAT IS IT?
This model simulates the behavior of different cooperation preference types observed in a repeated linear public goods game and how the interaction between the different types affects the dynamics of voluntary contributions. The model is based on the results from an experiment that was done with real human subjects by the researchers. 

Briefly, the public goods game is an environment where a group of N agents are given a certain endowment and have to make the decision of allocating this endowment between private consumption and the production of a public good. The utility an agent gets from one unit kept for private consumption is different from the utility an agent gets from one unit contributed towards a public good which is shared among all agents.

For more information about the linear public goods game, see Ledyard, 1995 and Chaudhuri, 2010. For more information about the experiment from which this model is originated, see the submitted paper.

## HOW IT WORKS
The main assumption underlying this model is that the different cooperative preference types of agents in a public goods setting have a major effect on the overall level of contribution to the public good. The model incorporates these different types of preferences by a set of programmed strategies based on experimental data. 

At the beginning, the user selects the number of agents of each preference type and sets the common parameters for all agents. At each tick, each agent receives a fixed endowment, then places a contribution to the public account according to its preference type and the average contribution of other agents in the previous tick. After each tick, the total and average contributions are calculated and tabulated. Also, the contribution and payoff of each preference type is calculated. 

The payoff function for each agent i is represented by:

πi = p (zi - yi) + (a / N ) * Y

In the equation, p is the is the return from each unit kept for private consumption; zi is the endowment given to each agent at the beginning each time period; yi is the amount an agent decides to contribute to the public good; a is the return from each unit contributed to the public good; N is the number of agents; and finally, Y is the total contribution to the public good by all agents.

There are seven preference types an agent can follow: free-riding, perfect conditional cooperation, above-diagonal conditional cooperation, below-diagonal conditional cooperation, alternating-diagonal conditional cooperation, triangular contribution, and random contribution. 

Consult submitted paper for more information on how preference types were elicited.


## HOW TO USE IT

#Buttons

Setup: Setup the world to begin simulating the N-agent repeated public goods game. The number of agents and their strategies are determined by the different preferences slider values.

Random Setup: Setup the world to begin simulating the N-agent repeated public goods game. The number of agents are determined by the Number-of-Agents slider but the preference types are going to be assigned randomly by the model.

Go: Have the agents with different preference types start interaction.


#Sliders

Profit-Factor-PublicGood:  is the return from each unit contributed to the public good.

Profit-Factor_PvtGood: the return from each unit kept for private consumption.

Initial-Endowment: the initial endowment each agent receives at the beginning of each tick.

Number-of-Agents: the number of agents that will be assigned to preferences randomly if the Random Setup is used.

#Preference Types:

Number-of-Freeriders: the number of agents with a preference to free-ride.

Number-of-PerfectConditionalCooperators: the number of agents with a preference to contribute the same amount as their peers.

Number-of-Above-Diagonal-ConditionalCooperators: the number of agents with a preference to contribute more than their peers.


Number-of-Below-Diagonal-ConditionalCooperators: the number of agents with a preference to contribute less than their peers.

Number-of-Alt-ConditionalCooperation: the number of agents with a preference to contribute more than their peers when the average contribution is less than half the endowment and a preference to contribute less than their peers when the average contribution is more than half the endowment.

Number-of-TriangularContributors: the number of agents with an increasing monotonic trend of contributions up to a certain level then a decreasing monotonic trend of contributions.

Number-of-RandomContributors: the number of agents with a preference to contribute a random amount.

#Monitors

Total Contribution: the total contribution of all agents in a given tick.

Mean Contribution: the average contribution of all agents in a given tick.

Num-Freeriders: the number of agents that the model assigned to be free-riders when using the Random Setup.

Num-PerfectCC: the number of agents that the model assigned to be perfect conditional cooperators when using the Random Setup.

Num-AboveCC: the number of agents that the model assigned to be above-diagonal conditional cooperators when using the Random Setup.

Num-BelowCC: the number of agents that the model assigned to be below-diagonal conditional cooperators when using the Random Setup.

Num-AltCC: the number of agents that the model assigned to be alternating-diagonal conditional cooperators when using the Random Setup.

Num-Tri: the number of agents that the model assigned to be triangular contributors when using the Random Setup.

Num-Random: the number of agents that the model assigned to be random contributors when using the Random Setup.

#Plots

Contribution: contribution plot for all agents.

Free-Riders Average Contribution and Payoff: average contribution and average payoff of free-riders.

Perfect Conditional Coops Average Contribution and Payoff: average contribution and average payoff of perfect conditional cooperators.

Above-Diagonal Conditional Coops Average Contribution and Payoff: average contribution and average payoff of above-diagonal conditional cooperators.

Below-Diagonal Conditional Coops Average Contribution and Payoff: average contribution and average payoff of below-diagonal conditional cooperators.

Alternating-Diagonal Conditional Coops Average Contribution and Payoff: average contribution and average payoff of alternating-diagonal conditional cooperators.

Triangular Contributors Average Contribution and Payoff: average contribution and average payoff of triangular contributors.

Random Contributors Average Contribution and Payoff: average contribution and average payoff of random contributors.



## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="validationG1" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>ticks &gt;= 10</exitCondition>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG2" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG3" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG5" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG6" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG7" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG8" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG9" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG11" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG12" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG13" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG14" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG15" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG16" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG17" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ValidationG18" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Prob-Mutation-to-Triangular">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-BelowCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-PerfectCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AboveCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-FreeRider">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Prob-Mutation-to-AltCondCoop">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ExampleDeclineSim1" repetitions="100" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="5"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="DecContSim1" repetitions="200" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_a" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_a2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_b" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_b2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_c" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_c2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_d" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_d2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_e" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_e2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_f" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="12.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_f2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="10"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="12.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_a1" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_a2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_a3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_a4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_b1" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_b2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_b3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_b4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_c1" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_c2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_c3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="7.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_c4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_d1" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="6.25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_d2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="12.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_d3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="18.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_d4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_e1" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="12.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_e2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_e3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="37.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_e4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_f1" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_f2" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_f3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_f4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_0" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_10" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_20" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_30" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_40" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_50" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_60" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_70" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_80" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_90" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_100" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FGF_Replication" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="17.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_0" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_10" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_20" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_30" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_40" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_50" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_60" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_70" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_80" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_90" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_100" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_a3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_b3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_c3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_d3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_e3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact1_DecContSim_f3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="12.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_a5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_b5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_c5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_d5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_e5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fact2_MPCR_f5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="200"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MyExp_Replication" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="21"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsCondCoop_FR10CondCoop90" repetitions="1000" runMetricsEveryStep="true">
    <setup>Percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsCondCoop_FR20CondCoop80" repetitions="1000" runMetricsEveryStep="true">
    <setup>Percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsCondCoop_FR30CondCoop70" repetitions="1000" runMetricsEveryStep="true">
    <setup>Percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsCondCoop_FR40CondCoop60" repetitions="1000" runMetricsEveryStep="true">
    <setup>Percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsCondCoop_FR50CondCoop50" repetitions="1000" runMetricsEveryStep="true">
    <setup>Percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsCondCoop_FR60CondCoop40" repetitions="1000" runMetricsEveryStep="true">
    <setup>Percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsCondCoop_FR70CondCoop30" repetitions="1000" runMetricsEveryStep="true">
    <setup>Percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsCondCoop_FR80CondCoop20" repetitions="1000" runMetricsEveryStep="true">
    <setup>Percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsCondCoop_FR90CondCoop10" repetitions="1000" runMetricsEveryStep="true">
    <setup>Percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="fr100" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR0BelowCC100" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR10BelowCC90" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="90"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR20BelowCC80" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="80"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR30BelowCC70" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="70"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR40BelowCC60" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="60"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR50BelowCC50" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR60BelowCC40" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="40"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR70BelowCC30" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR80BelowCC20" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsBelowCC_FR90BelowCC10" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR0PerfectCC100" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR10PerfectCC90" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR20PerfectCC80" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR30PerfectCC70" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR40PerfectCC60" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR50PerfectCC50" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR60PerfectCC40" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR70PerfectCC30" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR80PerfectCC20" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsPerfectCC_FR90PerfectCC10" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR0AboveCC100" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR10AboveCC90" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR20AboveCC80" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR30AboveCC70" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR40AboveCC60" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR50AboveCC50" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR60AboveCC40" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR70AboveCC30" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR80AboveCC20" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAboveCC_FR90AboveCC10" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR0AltCC100" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR10AltCC90" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR20AltCC80" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR30AltCC70" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR40AltCC60" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR50AltCC50" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR60AltCC40" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR70AltCC30" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR80AltCC20" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FRvsAltCC_FR90AltCC10" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_25" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FreeRiderPercentage_N=100_75" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_25" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CondCoopPercentage_N=100_75" repetitions="1000" runMetricsEveryStep="true">
    <setup>percentage-setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>count turtles with [strategy ="freeride"]</metric>
    <metric>count turtles with [strategy ="above-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="below-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="perfect-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="alt-conditional-cooperation"]</metric>
    <metric>count turtles with [strategy ="triangular-contribution"]</metric>
    <metric>count turtles with [strategy ="random"]</metric>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="fischrep" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>mean [contribution] of (turtles with [strategy = "freeride" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "perfect-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "above-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "below-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "triangular-contribution" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "random" ])</metric>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="17.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="fischrep_I=10" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>mean [contribution] of (turtles with [strategy = "freeride" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "perfect-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "above-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "below-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "triangular-contribution" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "random" ])</metric>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="17.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="fischrep_I=10_norand" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>mean [contribution] of (turtles with [strategy = "freeride" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "perfect-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "above-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "below-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "triangular-contribution" ])</metric>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="16.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="13"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ExpRep_withrand" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>mean [contribution] of (turtles with [strategy = "freeride"])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "perfect-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "above-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "alt-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "below-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "triangular-contribution" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "random" ])</metric>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="21"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ExpRep_withoutrand" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>total-contribution / count turtles</metric>
    <metric>mean [contribution] of (turtles with [strategy = "freeride"])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "perfect-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "above-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "alt-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "below-conditional-cooperation" ])</metric>
    <metric>mean [contribution] of (turtles with [strategy = "triangular-contribution" ])</metric>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="32"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="21"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="25"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR0.25_N4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR0.5_N4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR0.75_N4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR1_N4" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR0.25_N3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR0.5_N3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR0.75_N3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR1_N3" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR0.25_N5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="1.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR0.5_N5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR0.75_N5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="3.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MPCR1_N5" repetitions="1000" runMetricsEveryStep="true">
    <setup>random-setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>total-contribution / count turtles</metric>
    <enumeratedValueSet variable="Number-of-Alt-ConditionalCooperation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-PerfectConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Below-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor_PvtGood">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-TriangularContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentage-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Initial-Endowment">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Above-Diagonal-ConditionalCooperators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Profit-Factor-PublicGood">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-RandomContributors">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-FreeRiders">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Continuous?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
